@@ -4,8 +4,6 @@
 class MatterError(Exception):
     """Generic Matter exception."""
 
-    pass
-
 
 class NodeCommissionFailed(MatterError):
     """Error raised when interview of a device failed."""
@@ -19,6 +17,10 @@ class NodeNotReady(MatterError):
     """Error raised when performing action on node that has not been fully added."""
 
 
+class NodeNotResolving(MatterError):
+    """Error raised when resolving the node fails."""
+
+
 class NodeNotExists(MatterError):
     """Error raised when performing action on node that does not exist."""
 
